summaryrefslogtreecommitdiff
path: root/include/scsi/scsi_host.h
diff options
context:
space:
mode:
authorBart Van Assche <bvanassche@acm.org>2024-10-22 11:07:54 -0700
committerMartin K. Petersen <martin.petersen@oracle.com>2024-12-04 15:34:28 -0500
commit47c2e30afcec52968e50db01f92dda7d373042cb (patch)
treeb3132d7df23d35e0191435ed5a3180a7e88f020f /include/scsi/scsi_host.h
parented638918f4df39daa458435f0825b487c1f192c8 (diff)
scsi: Rename .device_configure() into .sdev_configure()
Improve naming consistency with the .sdev_prep() and .sdev_destroy() methods by renaming .device_configure() into .sdev_configure(). Cc: Christoph Hellwig <hch@lst.de> Acked-by: Damien Le Moal <dlemoal@kernel.org> Signed-off-by: Bart Van Assche <bvanassche@acm.org> Link: https://lore.kernel.org/r/20241022180839.2712439-3-bvanassche@acm.org Signed-off-by: Martin K. Petersen <martin.petersen@oracle.com>
Diffstat (limited to 'include/scsi/scsi_host.h')
-rw-r--r--include/scsi/scsi_host.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/scsi/scsi_host.h b/include/scsi/scsi_host.h
index 58b29cc6de09..7e1b1a54e46a 100644
--- a/include/scsi/scsi_host.h
+++ b/include/scsi/scsi_host.h
@@ -212,10 +212,10 @@ struct scsi_host_template {
*
* Status: OPTIONAL
*
* Note: slave_configure is the legacy version, use device_configure for
* all new code. A driver must never define both.
*/
- int (* device_configure)(struct scsi_device *, struct queue_limits *lim);
+ int (* sdev_configure)(struct scsi_device *, struct queue_limits *lim);
int (* slave_configure)(struct scsi_device *);
/*
@@ -212,10 +212,10 @@ struct scsi_host_template {
* Status: OPTIONAL
*
- * Note: slave_configure is the legacy version, use device_configure for
+ * Note: slave_configure is the legacy version, use sdev_configure for
* all new code. A driver must never define both.
*/